package com.frotscher.example.euro2016.model;

import java.util.Comparator;
import java.util.HashSet;
import java.util.Set;
import java.util.TreeSet;

public class Group {

	private Integer groupNumber;
	private String name;
	private Set<Team> teams;
	private Set<Match> matches;
	
	public Integer getGroupNumber() {
		return groupNumber;
	}

	public void setGroupNumber(Integer groupNumber) {
		this.groupNumber = groupNumber;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Set<Match> getMatches() {
		return matches;
	}

	public void setMatches(Set<Match> matches) {
		this.matches = matches;
	}
	
	public void addMatch(Match match) {
		if (matches==null) {
			matches = new TreeSet<>(new MatchComparatorByDate());
		}
		matches.add(match);
	}
	
	public Set<Team> getTeams() {
		return teams;
	}
	
	public void setTeams(Set<Team> teams) {
		this.teams = teams;
	}

	public void addTeam(Team team) {
		if (teams==null) {
			teams = new HashSet<>();
		}
		teams.add(team);
	}

	public GroupStandings getStandings() {
		return calcTable();
	}

	private GroupStandings calcTable() {
		GroupStandings standings = new GroupStandings();

		for (Team team : teams) {
			int points = 0;
			int goalsForTeam = 0;
			int goalsAgainstTeam = 0;
			
			for (Match match : matches) {
				Result result = match.getResult();
				if (result!=null && result.getHomeTeamGoals()!=null && result.getAwayTeamGoals()!=null) {
					if (team.equals(match.getHomeTeam())) {

						goalsForTeam += result.getHomeTeamGoals();
						goalsAgainstTeam += result.getAwayTeamGoals();
						points += getPointsForHomeTeam(result);
						
					} else if (team.equals(match.getAwayTeam())) {

						goalsForTeam += result.getAwayTeamGoals();
						goalsAgainstTeam += result.getHomeTeamGoals();
						points += getPointsForAwayTeam(result);
					}
				}
			}
			
			standings.addPosition(standings.new Position(team, points, goalsForTeam, goalsAgainstTeam));
		}
		
		return standings;
	}
	
	private int getPointsForAwayTeam(Result result) {
		if (result.getHomeTeamGoals() > result.getAwayTeamGoals()) {
			return 0;
		} else if (result.getHomeTeamGoals() < result.getAwayTeamGoals()) {
			return 3;
		} else {
			return 1;
		}
	}

	private int getPointsForHomeTeam(Result result) {
		if (result.getHomeTeamGoals() > result.getAwayTeamGoals()) {
			return 3;
		} else if (result.getHomeTeamGoals() < result.getAwayTeamGoals()) {
			return 0;
		} else {
			return 1;
		}
	}

	private class MatchComparatorByDate implements Comparator<Match> {
		@Override
		public int compare(Match m1, Match m2) {
			return m1.getMatchNumber().compareTo(m2.getMatchNumber());
		}
	}
}