package com.frotscher.example.euro2016.mvc.controller;

import java.util.List;

import javax.inject.Inject;
import javax.mvc.annotation.Controller;
import javax.mvc.binding.BindingResult;
import javax.validation.Valid;
import javax.validation.executable.ExecutableType;
import javax.validation.executable.ValidateOnExecution;
import javax.ws.rs.BeanParam;
import javax.ws.rs.Consumes;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.GenericEntity;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import com.frotscher.example.euro2016.model.Match;
import com.frotscher.example.euro2016.model.Result;
import com.frotscher.example.euro2016.mvc.ErrorDetails;
import com.frotscher.example.euro2016.repository.MatchRepository;

@Path("matches")
public class MatchController {

	@Inject
	private MatchRepository matchRepo;

	@Inject  
	private BindingResult br;
	
	@Inject
	private ErrorDetails errorDetails;
	
	@POST
	@Path("{matchNumber}")
	@Controller
	@Consumes("application/x-www-form-urlencoded")
	@ValidateOnExecution(type = ExecutableType.NONE)
	public String saveMatchResult(@Valid @BeanParam ResultForm form) {

		Match match = matchRepo.getMatch(form.getMatchNumber());
		
		if (br.isFailed()) {
			for (String msg : br.getAllMessages()) {
				errorDetails.addErrorMsg(msg);
			}

		} else {
			
			match.setResult(new Result(form.getHomeTeamGoals(), form.getAwayTeamGoals()));
			matchRepo.saveMatch(match);
		}

		return "redirect:stages/" + match.getStageNumber();
	}

	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public Response getAllMatches() {
		List<Match> allMatches = matchRepo.getAllMatches();
		
		GenericEntity<List<Match>> ge = new GenericEntity<List<Match>>(allMatches) {};
		return Response.ok().entity(ge).build();
	}
	
	@GET
	@Path("{matchId}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response getMatch(@PathParam("matchId") Integer matchId) {
		Match match = matchRepo.getMatches(matchId);
		
		if (match==null) {
			return Response.status(Status.NOT_FOUND).build();
		}
		
		return Response.ok().entity(match).build();
	}
}