package com.frotscher.example.euro2016.repository;

import java.time.LocalDateTime;
import java.time.Month;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.annotation.PostConstruct;
import javax.inject.Singleton;

import com.frotscher.example.euro2016.model.Match;
import com.frotscher.example.euro2016.model.Team;

@Singleton
public class MatchRepository {

	private Map<Integer, Match> matches = new ConcurrentHashMap<>();
	
	
	public List<Match> getAllMatches() {
		List<Match> matchList = new ArrayList<>(matches.values());
		return matchList;
	}
	
	public Match getMatches(Integer matchNumber) {
		return matches.get(matchNumber);
	}

	public List<Match> getMatchesForStage(Integer stageNumber) {
		List<Match> stageMatches= new ArrayList<>();
			
		for (Match m : matches.values()) {
			if (m.getStageNumber()==stageNumber) {
				stageMatches.add(m);
			}
		}
	
		return stageMatches;
	}
	
	public Match getMatch(Integer matchNumber) {
		return matches.get(matchNumber);
	}
	 
	public void saveMatch(Match match) {
		matches.put(match.getMatchNumber(), match);
	}
	
	
	@PostConstruct
	public void init() {
		Team fra = new Team("France");
		Team rum = new Team("Romania");
		Team alb = new Team("Albania");
		Team sui = new Team("Switzerland");
		saveMatch(new Match(1, 1, 1, LocalDateTime.of(2016, Month.JUNE, 10, 21, 0), fra, rum));
		saveMatch(new Match(2, 1, 1, LocalDateTime.of(2016, Month.JUNE, 11, 15, 0), alb, sui));
		saveMatch(new Match(3, 1, 1, LocalDateTime.of(2016, Month.JUNE, 15, 18, 0), rum, sui));
		saveMatch(new Match(4, 1, 1, LocalDateTime.of(2016, Month.JUNE, 15, 21, 0), fra, alb));
		saveMatch(new Match(5, 1, 1, LocalDateTime.of(2016, Month.JUNE, 19, 21, 0), fra, sui));
		saveMatch(new Match(6, 1, 1, LocalDateTime.of(2016, Month.JUNE, 19, 21, 0), rum, alb));
		
		Team wal = new Team("Wales");
		Team slo = new Team("Slovakia");
		Team eng = new Team("England");
		Team rus = new Team("Russia");
		saveMatch(new Match(7, 1, 2, LocalDateTime.of(2016, Month.JUNE, 11, 18, 0), wal, slo));
		saveMatch(new Match(8, 1, 2, LocalDateTime.of(2016, Month.JUNE, 11, 21, 0), eng, rus));
		saveMatch(new Match(9, 1, 2, LocalDateTime.of(2016, Month.JUNE, 15, 15, 0), rus, slo));
		saveMatch(new Match(10, 1, 2, LocalDateTime.of(2016, Month.JUNE, 16, 15, 0), eng, wal));
		saveMatch(new Match(11, 1, 2, LocalDateTime.of(2016, Month.JUNE, 20, 21, 0), slo, eng));
		saveMatch(new Match(12, 1, 2, LocalDateTime.of(2016, Month.JUNE, 20, 21, 0), rus, wal));
		
		Team pol = new Team("Poland");
		Team nir = new Team("Northern Ireland");
		Team ger = new Team("Germany");
		Team ukr = new Team("Ukraine");
		saveMatch(new Match(13, 1, 3, LocalDateTime.of(2016, Month.JUNE, 12, 18, 0), pol, nir));
		saveMatch(new Match(14, 1, 3, LocalDateTime.of(2016, Month.JUNE, 12, 21, 0), ger, ukr));
		saveMatch(new Match(15, 1, 3, LocalDateTime.of(2016, Month.JUNE, 16, 18, 0), ukr, nir));
		saveMatch(new Match(16, 1, 3, LocalDateTime.of(2016, Month.JUNE, 16, 21, 0), ger, pol));
		saveMatch(new Match(17, 1, 3, LocalDateTime.of(2016, Month.JUNE, 21, 18, 0), nir, ger));
		saveMatch(new Match(18, 1, 3, LocalDateTime.of(2016, Month.JUNE, 21, 18, 0), ukr, pol));
		
		Team tur = new Team("Turkey");
		Team cro = new Team("Croatia");
		Team esp = new Team("Spain");
		Team cze = new Team("Czech Republic");
		saveMatch(new Match(19, 1, 4, LocalDateTime.of(2016, Month.JUNE, 12, 15, 0), tur, cro));
		saveMatch(new Match(20, 1, 4, LocalDateTime.of(2016, Month.JUNE, 13, 15, 0), esp, cze));
		saveMatch(new Match(21, 1, 4, LocalDateTime.of(2016, Month.JUNE, 17, 18, 0), cze, cro));
		saveMatch(new Match(22, 1, 4, LocalDateTime.of(2016, Month.JUNE, 17, 21, 0), esp, tur));
		saveMatch(new Match(23, 1, 4, LocalDateTime.of(2016, Month.JUNE, 21, 21, 0), cro, esp));
		saveMatch(new Match(24, 1, 4, LocalDateTime.of(2016, Month.JUNE, 21, 21, 0), cze, tur));

		Team ire = new Team("Ireland");
		Team swe = new Team("Sweden");
		Team bel = new Team("Belgium");
		Team ita = new Team("Italy");
		saveMatch(new Match(25, 1, 5, LocalDateTime.of(2016, Month.JUNE, 13, 18, 0), ire, swe));
		saveMatch(new Match(26, 1, 5, LocalDateTime.of(2016, Month.JUNE, 13, 21, 0), bel, ita));
		saveMatch(new Match(27, 1, 5, LocalDateTime.of(2016, Month.JUNE, 17, 15, 0), ita, swe));
		saveMatch(new Match(28, 1, 5, LocalDateTime.of(2016, Month.JUNE, 18, 15, 0), bel, ire));
		saveMatch(new Match(29, 1, 5, LocalDateTime.of(2016, Month.JUNE, 22, 21, 0), swe, bel));
		saveMatch(new Match(30, 1, 5, LocalDateTime.of(2016, Month.JUNE, 22, 21, 0), ita, ire));

		Team aut = new Team("Austria");
		Team hun = new Team("Hungary");
		Team por = new Team("Portugal");
		Team ice = new Team("Iceland");
		saveMatch(new Match(31, 1, 6, LocalDateTime.of(2016, Month.JUNE, 14, 18, 0), aut, hun));
		saveMatch(new Match(32, 1, 6, LocalDateTime.of(2016, Month.JUNE, 14, 21, 0), por, ice));
		saveMatch(new Match(33, 1, 6, LocalDateTime.of(2016, Month.JUNE, 18, 18, 0), ice, hun));
		saveMatch(new Match(34, 1, 6, LocalDateTime.of(2016, Month.JUNE, 18, 21, 0), por, aut));
		saveMatch(new Match(35, 1, 6, LocalDateTime.of(2016, Month.JUNE, 22, 18, 0), hun, por));
		saveMatch(new Match(36, 1, 6, LocalDateTime.of(2016, Month.JUNE, 22, 18, 0), ice, aut));

		// round of 16
		saveMatch(new Match(37, 2, null, LocalDateTime.of(2016, Month.JUNE, 25, 15, 0), new Team("Runner-up Group A"), new Team("Runner-up C")));
		saveMatch(new Match(38, 2, null, LocalDateTime.of(2016, Month.JUNE, 25, 18, 0), new Team("Winner B"), new Team("Third-place A/C/D")));
		saveMatch(new Match(39, 2, null, LocalDateTime.of(2016, Month.JUNE, 25, 21, 0), new Team("Winner D"), new Team("Third-place B/E/F")));
		saveMatch(new Match(40, 2, null, LocalDateTime.of(2016, Month.JUNE, 26, 15, 0), new Team("Winner A"), new Team("Third-place C/D/E")));
		saveMatch(new Match(41, 2, null, LocalDateTime.of(2016, Month.JUNE, 26, 18, 0), new Team("Winner C"), new Team("Third-place A/B/F")));
		saveMatch(new Match(42, 2, null, LocalDateTime.of(2016, Month.JUNE, 26, 21, 0), new Team("Winner F"), new Team("Runner-up E")));
		saveMatch(new Match(43, 2, null, LocalDateTime.of(2016, Month.JUNE, 27, 18, 0), new Team("Winner E"), new Team("Runner-up D")));
		saveMatch(new Match(44, 2, null, LocalDateTime.of(2016, Month.JUNE, 27, 21, 0), new Team("Runner-up B"), new Team("Runner-up F")));

		// quarter-finals
		saveMatch(new Match(45, 3, null, LocalDateTime.of(2016, Month.JUNE, 30, 21, 0), new Team("Winner Match 1"), new Team("Winner Match 3")));
		saveMatch(new Match(46, 3, null, LocalDateTime.of(2016, Month.JULY,  1, 21, 0), new Team("Winner Match 2"), new Team("Winner Match 6")));
		saveMatch(new Match(47, 3, null, LocalDateTime.of(2016, Month.JULY,  2, 21, 0), new Team("Winner Match 5"), new Team("Winner Match 7")));
		saveMatch(new Match(48, 3, null, LocalDateTime.of(2016, Month.JULY,  3, 21, 0), new Team("Winner Match 4"), new Team("Winner Match 8")));

		// semi-finals
		saveMatch(new Match(49, 4, null, LocalDateTime.of(2016, Month.JULY,  6, 21, 0), new Team("Winner QF1"), new Team("Winner QF2")));
		saveMatch(new Match(50, 4, null, LocalDateTime.of(2016, Month.JULY,  7, 21, 0), new Team("Winner QF3"), new Team("Winner QF4")));

		//final
		saveMatch(new Match(51, 5, null, LocalDateTime.of(2016, Month.JULY, 10, 21, 0), new Team("Winner SF1"), new Team("Winner SF2")));
	}
}
