package com.frotscher.example.euro2016.repository;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;
import javax.inject.Singleton;

import com.frotscher.example.euro2016.model.Group;
import com.frotscher.example.euro2016.model.GroupStage;
import com.frotscher.example.euro2016.model.KnockoutStage;
import com.frotscher.example.euro2016.model.Match;
import com.frotscher.example.euro2016.model.Stage;

@Singleton
public class StageRepository {

	@Inject
	private MatchRepository matchRepo;
	
	public Stage getStage(Integer stageNumber) {
		
		Stage stage;
		
		switch(stageNumber) {
			case 1:	stage = createGroupStage(stageNumber); break;
			case 2: stage = createKnockoutStage(stageNumber); break;
			case 3: stage = createKnockoutStage(stageNumber); break;
			case 4: stage = createKnockoutStage(stageNumber); break;
			case 5: stage = createKnockoutStage(stageNumber); break;
			default: throw new IllegalArgumentException("Invalid stage number");
		}
		
		return stage;
	}

	private Stage createKnockoutStage(Integer stageNumber) {

		List<Match> stageMatches = matchRepo.getMatchesForStage(stageNumber);

		KnockoutStage stage = new KnockoutStage();
		stage.setStageNumber(stageNumber);
		stage.setName("Round of 16");
		stage.setMatches(stageMatches);
		
		return stage;
	}

	private GroupStage createGroupStage(Integer stageNumber) {
		List<Match> stageMatches = matchRepo.getMatchesForStage(stageNumber);

		GroupStage stage = new GroupStage();
		stage.setStageNumber(stageNumber);
		stage.setName("Group Stage");
		
		List<Group> groups = new ArrayList<>();

		Group groupA = new Group();
		groupA.setGroupNumber(1);
		groupA.setName("A");
		populateGroup(groupA, stageMatches);
		groups.add(groupA);

		Group groupB = new Group();
		groupB.setGroupNumber(2);
		groupB.setName("B");
		populateGroup(groupB, stageMatches);
		groups.add(groupB);

		Group groupC = new Group();
		groupC.setGroupNumber(3);
		groupC.setName("C");
		populateGroup(groupC, stageMatches);
		groups.add(groupC);

		Group groupD = new Group();
		groupD.setGroupNumber(4);
		groupD.setName("D");
		populateGroup(groupD, stageMatches);
		groups.add(groupD);

		Group groupE = new Group();
		groupE.setGroupNumber(5);
		groupE.setName("E");
		populateGroup(groupE, stageMatches);
		groups.add(groupE);

		Group groupF = new Group();
		groupF.setGroupNumber(6);
		groupF.setName("F");
		populateGroup(groupF, stageMatches);
		groups.add(groupF);

		stage.setGroups(groups);
		return stage;
	}

	private void populateGroup(Group group, List<Match> stageMatches) {
		for (Match match : stageMatches) {
			if (match.getGroupNumber()==group.getGroupNumber()) {
				group.addMatch(match);
				group.addTeam(match.getHomeTeam());
				group.addTeam(match.getAwayTeam());
			}
		}
	}
}
